@@ -1,12 +1,17 @@
 package DTL::Fast::Text;
 use strict; use utf8; use warnings FATAL => 'all'; 
 
+use DTL::Fast::Template;
+
 sub new
 {
-    my $proto = shift;
-    my $text = shift // '';
+    my ($proto, $text ) = @_;
+    $text //= '';
     
-    return bless {'texts' => [$text]}, $proto;
+    return bless {
+        'texts' => [$text]
+        , 'source_line' => $DTL::Fast::Template::CURRENT_TEMPLATE_LINE
+    }, $proto;
 }
 
 sub append
